"""This is nester.py module. This module has the iter() function. This function is used for iterating through the lists."""
# iter(l) function takes one list parameter. It prints out each element from the provided list, even if the list has multiple nested lists.


def iter(l, level=0):
# Second argument is for providing the number of tab stops while printing the nested list.
# second argument has a default value making it as an optional argument.

	for i in l:
		if isinstance(i, list):
			iter(i,level+1)
		else:
			for tab in range(level):
				print("\t" , end='')
			print(i)	


from distutils.core import setup

setup(

       name    = 'nestersru',
       version = '1.1.3',
       py_modules =['nestersru'],
       author = 'hfpython',
       author_email ='hfpython@headfirstlabs.com',
       url          = 'http://www.headfirstlabs.com',
       description   = 'A simple printer of nested lists',

       )
